Skip to contents

internal function to combine new xQTL test results with existing XqtlExperiment instance

Usage

add_scores(xse, mat, check.cols = TRUE)

Arguments

xse

XqtlExperiment instance

mat

a matrix of test results conformant with the XqtlExperiment: rownames agree,

check.cols

logical(1) will message if redundant variants are found when new scores are bound in columns will be added to the mcols(rowRanges(xse))